import 'package:restoque_build/src/model/requestBody.dart';

///The name of the entity that will be saved in the database.
///
///*Example:*
///
///   @RestoqueEntity("Customer")
class RestoqueEntity {
  final String tableName;
  const RestoqueEntity(this.tableName);
}

///Indicates which property will be the primary key to entity.
///Accepts more than one.
///
///**Example:**
///
///   @RestoqueEntityKey()
///
///   int idCustomer;
class RestoqueEntityKey {
  const RestoqueEntityKey();
}

///Indicates that the property has a different name.
///
///**Example:**
///
///   RestoquePropertyName("customer_name")
///
///   String customerName;
class RestoquePropertyName {
  final String name;
  const RestoquePropertyName({this.name});
}

///Indicates the http method is GET
///
/// expected path as a parameter
/// {@category Http}
class Get {
  final String path;
  const Get(this.path);
}

///Indicates the http method is POST
///
/// expected path as a parameter
/// {@category Http}
class Post {
  final String path;
  const Post(this.path);
}

///Indicates the http method is PUT
///
/// expected path as a parameter
/// {@category Http}
class Put {
  final String path;
  const Put(this.path);
}

///Indicates the http method is DELETE
///
/// expected path as a parameter
/// {@category Http}
class Delete {
  final String path;
  const Delete(this.path);
}

///Body of POST request
///
/// expected path as a parameter
/// {@category Http}
class Body {
  final RequestBody body;
  const Body(this.body);
}

///Header of http request
///
/// expected path as a parameter
/// {@category Http}
class Header {
  final String header;
  const Header(this.header);
}
